@@ -4,21 +4,20 @@ test_that("estimate_mean_sd_nn works as expected!", {
   data <- generate_synthetic_data(sample_size = 200, gps_spec = 3)
 
   # Estimate GPS function
-  GPS_m <- train_gps(cov_mt = data[, -(1:2)],
-                     w_all = data$treat,
-                     sl_lib = c("SL.xgboost"),
-                     dnorm_log = FALSE)
+  gps_m <- estimate_gps(cov_mt = data[, -(1:2)],
+                        w_all = data$treat,
+                        sl_lib = c("SL.xgboost"),
+                        dnorm_log = FALSE)
 
   # Hyperparameter
   hyperparam <- c(0.1, 0.2, 1)
   n_neighbor <- 15
-  expand <- 1
   block_size <- 10000
 
   # compute noise
   noise <- estimate_noise_nn(hyperparam = hyperparam,
                              w_obs = data$treat,
-                             GPS_obs = GPS_m$GPS,
+                             GPS_obs = gps_m$gps$gps,
                              y_obs = data$Y,
                              n_neighbor = n_neighbor,
                              nthread = 1)
@@ -30,11 +29,10 @@ test_that("estimate_mean_sd_nn works as expected!", {
                              w_obs = data$treat,
                              w = w,
                              y_obs = data$Y,
-                             GPS_m = GPS_m,
+                             gps_m = gps_m,
                              n_neighbor = n_neighbor,
-                             expand = expand,
                              block_size = block_size)
 
   expect_equal(length(val), 21)
-  expect_equal(val[10], 5.068975, tolerance = 0.0001)
+  expect_equal(val[10], 5.031225, tolerance = 0.0001)
 })
